@@ -2,7 +2,6 @@ import dask.array as da
 import matplotlib
 import numpy as np
 import scanpy as sc
-from matplotlib import pyplot as plt
 from matplotlib.colors import Normalize
 from spatial_image import to_spatial_image
 from spatialdata import SpatialData
@@ -49,9 +48,6 @@ class TestImages(PlotTester, metaclass=PlotTesterMeta):
     def test_plot_can_render_a_single_channel_from_multiscale_image(self, sdata_blobs: SpatialData):
         sdata_blobs.pl.render_images(element="blobs_multiscale_image", channel=0).pl.show()
 
-    def test_plot_can_render_a_single_channel_from_image_no_el(self, sdata_blobs: SpatialData):
-        sdata_blobs.pl.render_images(channel=0).pl.show()
-
     def test_plot_can_render_a_single_channel_str_from_image(self, sdata_blobs_str: SpatialData):
         sdata_blobs_str.pl.render_images(element="blobs_image", channel="c1").pl.show()
 
@@ -70,16 +66,13 @@ class TestImages(PlotTester, metaclass=PlotTesterMeta):
     def test_plot_can_render_two_channels_str_from_multiscale_image(self, sdata_blobs_str: SpatialData):
         sdata_blobs_str.pl.render_images(element="blobs_multiscale_image", channel=["c1", "c2"]).pl.show()
 
-    def test_plot_can_pass_vmin_vmax(self, sdata_blobs: SpatialData):
-        fig, axs = plt.subplots(ncols=2, figsize=(6, 3))
-        sdata_blobs.pl.render_images(element="blobs_image", channel=1).pl.show(ax=axs[0])
-        sdata_blobs.pl.render_images(element="blobs_image", channel=1, vmin=0, vmax=0.4).pl.show(ax=axs[1])
-
-    def test_plot_can_pass_normalize(self, sdata_blobs: SpatialData):
-        fig, axs = plt.subplots(ncols=2, figsize=(6, 3))
+    def test_plot_can_pass_normalize_clip_True(self, sdata_blobs: SpatialData):
         norm = Normalize(vmin=0, vmax=0.4, clip=True)
-        sdata_blobs.pl.render_images(element="blobs_image", channel=1).pl.show(ax=axs[0])
-        sdata_blobs.pl.render_images(element="blobs_image", channel=1, norm=norm).pl.show(ax=axs[1])
+        sdata_blobs.pl.render_images(element="blobs_image", channel=0, norm=norm).pl.show()
+
+    def test_plot_can_pass_normalize_clip_False(self, sdata_blobs: SpatialData):
+        norm = Normalize(vmin=0, vmax=0.4, clip=False)
+        sdata_blobs.pl.render_images(element="blobs_image", channel=0, norm=norm).pl.show()
 
     def test_plot_can_pass_color_to_single_channel(self, sdata_blobs: SpatialData):
         sdata_blobs.pl.render_images(element="blobs_image", channel=1, palette="red").pl.show()
@@ -97,9 +90,6 @@ class TestImages(PlotTester, metaclass=PlotTesterMeta):
             element="blobs_image", channel=[0, 1, 2], cmap=["Reds", "Greens", "Blues"]
         ).pl.show()
 
-    def test_plot_can_normalize_image(self, sdata_blobs: SpatialData):
-        sdata_blobs.pl.render_images(element="blobs_image", percentiles_for_norm=(5, 90)).pl.show()
-
     def test_plot_can_render_multiscale_image(self, sdata_blobs: SpatialData):
         sdata_blobs.pl.render_images("blobs_multiscale_image").pl.show()
 
